==> renku-0.9.2.dev9-py2.py3-none-any.whl: renku/service/jobs/datasets.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Dataset jobs."""
from urllib3.exceptions import HTTPError

from renku.core.commands.dataset import import_dataset
from renku.core.errors import DatasetExistsError, ParameterError
from renku.core.management.datasets import DownloadProgressCallback
from renku.core.utils.contexts import chdir
from renku.service.jobs.constants import USER_JOB_STATE_COMPLETED, \
    USER_JOB_STATE_FAILED, USER_JOB_STATE_IN_PROGRESS
from renku.service.serializers.jobs import UserJob
from renku.service.utils import make_project_path, repo_sync
from renku.service.views.decorators import requires_cache


def fail_job(cache, user_job, user, error):
    """Mark job as failed."""
    user_job['state'] = USER_JOB_STATE_FAILED

    if 'extras' not in user_job:
        user_job['extras'] = {}

    user_job['extras']['error'] = error
    cache.set_job(user, user_job)


class DatasetImportJobProcess(DownloadProgressCallback):
    """Track dataset import job progress."""

    schema = UserJob()

    def __init__(self, cache, user, job):
        """Construct dataset import job progress."""
        self.cache = cache
        self.user = user
        self.job = job

        super().__init__(None, None)

    def __call__(self, description, total_size):
        """Job progress call."""
        self.job['state'] = USER_JOB_STATE_IN_PROGRESS
        self.job['extras'] = {
            'description': description,
            'total_size': total_size,
        }

        self.cache.set_job(self.user, self.job)
        super().__init__(description, total_size)

        return self

    def update(self, size):
        """Update status."""
        self.job['extras']['progress_size'] = size
        self.cache.set_job(self.user, self.job)

    def finalize(self):
        """Finalize job tracking."""
        self.job['state'] = USER_JOB_STATE_COMPLETED
        self.cache.set_job(self.user, self.job)


@requires_cache
def dataset_import(
    cache,
    user,
    user_job_id,
    project_id,
    dataset_uri,
    short_name=None,
    extract=False,
    timeout=None,
):
    """Job for dataset import."""
    user_job = cache.get_job(user, user_job_id)
    project = cache.get_project(user, project_id)
    project_path = make_project_path(user, project)

    with chdir(project_path):
        try:
            import_dataset(
                dataset_uri,
                short_name,
                extract,
                commit_message=f'service: dataset import {dataset_uri}',
                progress=DatasetImportJobProcess(cache, user, user_job)
            )
        except (HTTPError, ParameterError, DatasetExistsError) as exp:
            fail_job(cache, user_job, user, str(exp))

            # Reraise exception, so we see trace in job metadata.
            raise exp

    if not repo_sync(project_path):
        error = 'failed to push refs'
        fail_job(cache, user_job, user, error)

        raise RuntimeError(error)

==> renku-0.10.3.dev10-py2.py3-none-any.whl: renku/service/jobs/datasets.py <==
# -*- coding: utf-8 -*-
#
# Copyright 2020 - Swiss Data Science Center (SDSC)
# A partnership between École Polytechnique Fédérale de Lausanne (EPFL) and
# Eidgenössische Technische Hochschule Zürich (ETHZ).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Dataset jobs."""
from urllib3.exceptions import HTTPError

from renku.core.commands.dataset import add_file, import_dataset
from renku.core.errors import DatasetExistsError, ParameterError
from renku.core.management.datasets import DownloadProgressCallback
from renku.core.utils.contexts import chdir
from renku.service.cache.serializers.job import JobSchema
from renku.service.utils import repo_sync
from renku.service.views.decorators import requires_cache


class DatasetImportJobProcess(DownloadProgressCallback):
    """Track dataset import job progress."""

    schema = JobSchema()

    def __init__(self, cache, job):
        """Construct dataset import job progress."""
        self.cache = cache
        self.job = job

        super().__init__(None, None)

    def __call__(self, description, total_size):
        """Job progress call."""
        self.job.extras = {
            'description': description,
            'total_size': total_size,
        }

        super().__init__(description, total_size)
        return self

    def update(self, size):
        """Update status."""
        self.job.extras['progress_size'] = size
        self.job.save()

    def finalize(self):
        """Finalize job tracking."""
        self.job.complete()


@requires_cache
def dataset_import(
    cache,
    user,
    user_job_id,
    project_id,
    dataset_uri,
    short_name=None,
    extract=False,
    timeout=None,
):
    """Job for dataset import."""
    user = cache.ensure_user(user)
    user_job = cache.get_job(user, user_job_id)
    project = cache.get_project(user, project_id)

    with chdir(project.abs_path):
        try:
            user_job.in_progress()
            import_dataset(
                dataset_uri,
                short_name,
                extract,
                commit_message=f'service: dataset import {dataset_uri}',
                progress=DatasetImportJobProcess(cache, user_job)
            )
            user_job.complete()
        except (HTTPError, ParameterError, DatasetExistsError) as exp:
            user_job.fail_job(str(exp))

            # Reraise exception, so we see trace in job metadata.
            raise exp

    if not repo_sync(project.abs_path):
        error = 'failed to push refs'
        user_job.fail_job(error)

        raise RuntimeError(error)


@requires_cache
def dataset_add_remote_file(
    cache, user, user_job_id, project_id, create_dataset, commit_message,
    dataset_name, url
):
    """Add a remote file to a specified dataset."""
    user = cache.ensure_user(user)
    user_job = cache.get_job(user, user_job_id)
    project = cache.get_project(user, project_id)

    try:
        user_job.in_progress()

        with chdir(project.abs_path):
            urls = url if isinstance(url, list) else [url]
            add_file(
                urls,
                dataset_name,
                create=create_dataset,
                commit_message=commit_message
            )

            if not repo_sync(project.abs_path):
                user_job.fail_job('repo sync failed')

            user_job.complete()
    except (HTTPError, BaseException) as e:
        user_job.fail_job(str(e))
